==> tine20-allinone_2019.12.5.tar.bz2: Filemanager/js/Filemanager-lang-nl_NL-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Filemanager **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Dutch (Netherlands) (http://www.transifex.com/tine20/tine20/language/nl_NL/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: nl_NL\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Upload Failed"
: "Upload mislukt"

, "Putting files in this folder is not allowed!"
: "Plaatsen van bestanden in deze folder is niet toegestaan!"

, "Filemanager"
: "Bestandsbeheerder"

, "Save locally"
: "Bewaar lokaal"

, "Tags"
: "Tags"

, "Name"
: "Naam"

, "Size"
: "Grootte"

, "Contenttype"
: "Inhoud"

, "Folder, Folders"
: [
  "Folder"
 ,"Folders"

]
, "Creation Time"
: "Tijdstip aanmaak"

, "Created By"
: "Aangemaakt door"

, "Last Modified Time"
: "Laatst gewijzigd op"

, "Last Modified By"
: "Laatst gewijzigd door"

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Indexed"
: ""

, "File contents is part of the search index"
: ""

, "Upload"
: "Upload"

, "Open Data Safe"
: ""

, "Folder Up"
: "Folder omhoog"

, "Close Data Safe"
: ""

, "Node Download Links"
: "Knooppunt Download Links"

, "Url"
: "Url"

, "Password"
: ""

, "Valid until"
: ""

, "Send as e-mail"
: ""

, "Download"
: ""

, "Service Unavailable"
: "Service niet beschikbaar"

, "The Filemanager is not configured correctly. Please refer to the {0}Tine 2.0 Admin FAQ{1} for configuration advice or contact your administrator."
: "Bestandsbeheer is niet juist geconfigureerd. Raadpleeg de {0} Tine 2.0 Admin FAQ {1} voor advies of neem contact op met de beheerder."

, "Files already exists"
: "Bestand bestaat reeds"

, "Do you want to replace the following file(s)?"
: "Bestand(en) verplaatsten?"

, "Failure on create folder"
: "Fout bij aanmaken folder"

, "Item with this name already exists!"
: "Item met deze naam bestaat al!"

, "Revision"
: "Versie"

, "This folder has own revision settings"
: ""

, "Revision active"
: ""

, "Limit revision amount to"
: ""

, "Hold-back in months"
: ""

, "path"
: "path"

, "Notifications"
: ""

, "This folder has own notification settings"
: ""

, "Reload"
: ""

, "Create Folder"
: "Maak folder"

, "New Folder"
: "Nieuwe folder"

, "Please enter the name of the new folder:"
: "Geef de naam van de nieuwe folder:"

, "No {0} added"
: "Geen {0} toegevoegd"

, "You have to supply a {0} name!"
: "Er moet een {0} naam worden opgegeven!"

, "Edit Properties"
: "Bewerk eigenschappen"

, "Rename"
: ""

, "Rename {0}"
: ""

, "Please enter the new name of the {0}:"
: "Voer de nieuwe naam van de {0} in:"

, "Not renamed {0}"
: "{0} niet hernoemd"

, "System Link"
: ""

, "Use this link to share the entry with other system users"
: ""

, "Delete"
: "Verwijder"

, "Do you really want to delete the following files?"
: "Mogewn de volgende bestanden echt worden verwijderd?"

, "Move"
: ""

, "Move Items"
: ""

, "Preview"
: ""

, "Publish"
: "Publiceer"

, "Public download links can be password protected. If left blank anyone who knows the link can download the selected files."
: ""

, "Folder has been published successfully"
: "Map is met succes gepubliceerd"

, "File has been published successfully"
: "Bestand is met succes gepubliceerd"

, "File, Files"
: [
  "Bestand"
 ,"Bestanden"

]
, "The grant to download files"
: ""

, "The grant to create anonymous download links for files"
: ""

, "Copying data .. {0}"
: "Kopieren gegevens... {0}"

, "Moving data .. {0}"
: "Verplaatsen gegevens... {0}"

, "Please wait"
: "Moment"

, "Quick Search"
: "Snel zoeken"

, "Type"
: "Type"

, "Description"
: "Omschrijving"

, "File Contents"
: ""

, "Download Link, Download Links"
: [
  ""
 ,""

]
, "Grants"
: ""

, "This folder has own grants"
: ""

, "Grants of a folder also apply recursively for all of its sub folders as long they don't have own grants itself."
: ""

, "This folder is part of the data safe"
: ""

, "If data safe protection is enabled, this folder and all it's contents is only shown if the data safe is opened."
: ""

, "Sorry, Tine 2.0 would like to show you the contents of the file displayed."
: ""

, "This is possible for .doc, .jpg, .pdf and even more file formats."
: ""

, "Interested? Then let us know!"
: ""

, "We are happy make you a non-binding offer."
: ""

, "No preview available."
: ""

, "Notification"
: ""

, "Notification active"
: ""

, "Summary"
: ""

, "Once a Day, Every {0} Days"
: [
  ""
 ,""

]
, "No"
: ""

, "Don't summarize"
: ""

, "Once a day"
: ""

, "Every 3 days"
: ""

, "Once a week"
: ""

, "Once a month"
: ""

, "Once a year"
: ""

, "Search for users ..."
: ""

, "No permission"
: ""

, "all"
: ""

, "Remove record"
: "Verwijder record"

, "Search for groups ..."
: ""

, "Close"
: ""

, "Loading preview ..."
: ""

, "Edit folder"
: "M"

, "edit file"
: "Bewerk bestand"

, "Public Links"
: "Publieke links"

, "Not yet indexed"
: ""

, "Modified By"
: "Gewijzigd door"

, "Last Modified"
: "Laatst gewijzigd"

, "Enter description"
: "Voer omschrijving in"

, "Select a file"
: ""

, "Select files"
: ""

, "Select a folder"
: ""

, "Select folders"
: ""

, "Select an item"
: ""

, "Select items"
: ""

, "Create Public Link"
: "Maak publieke link"

, "Creating new Download Link..."
: "Maak nieuwe download link..."

, "Deleting Download Links..."
: "Verwijder dowload links..."

, "Deleting Download Link..."
: "Download links verwijderen..."

, "Expiration Time"
: "Vervaltijd"

, "Access Count"
: ""

, "Usage"
: ""

, "This folder has own quota"
: ""

, "Quota"
: ""

, "no quota set"
: ""

, "Current Usage"
: ""

, "The Quota applies recursively for files and subfolders. Please note, the Effective Quota differs wehn a parent folder has set a lower quota."
: ""

, "File Type"
: ""

, "Usage by File Type"
: ""

, "User"
: ""

, "Usage by User"
: ""

, "unknown"
: ""

, "Whole Filemanager"
: ""

, "This Folder"
: ""

, "Search"
: ""

, "Row double click default"
: ""

, "Defines which action should be executed on double click by default?"
: ""

, "Password for download required"
: ""

, "Submit"
: ""

, "File not found!"
: ""

, "Public Download URL"
: ""

, "Serve anonymous downloads from a different URL. Make sure to setup proper rewrite rules."
: ""

, "manage shared folders"
: "beheer gedeelde folders"

, "Create new shared folders"
: "Maak een nieuwe gedeelde folder"

, "Manage anonymous download links"
: "Beheer anonieme download links"

, "Allow to see, add and delete download links of files and folders"
: "Zien, toevoegen en verwijderen download links van bestanden en mappen"

, "Destination is a Subfolder"
: "Bestemming is een submap"

, "The destination is a subfolder. It is not allowed to copy or move a folder into one of its subfolders."
: "De bestemming is een submap. Het is niet toegestaan om te kopiëren of verplaatsen van een map in een van de submappen."

, "Destination has the same Path"
: "Bestemming heeft dezelfde pad"

, "The destination has the same path the source has. No action has been performed."
: "De bestemming heeft dezelfde pad de bron. Geen actie is uitgevoerd."

, "My folders"
: "Mijn folders"

, "Shared folders"
: "Gedeelde folders"

, "Other users folders"
: "Folders van andere gebruikers"

, "Received"
: ""

, "To"
: ""

, "Cc"
: ""

, "Bcc"
: ""

, "From (E-Mail)"
: ""

, "From (Name)"
: ""

, "Body"
: ""

, "Attachments"
: ""

, "Folder"
: "Folder"

, "File"
: "Bestand"

, "Download Link"
: ""

, "Once a Day"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.03.4.tar.bz2: Filemanager/js/Filemanager-lang-nl_NL-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Filemanager **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Dutch (Netherlands) (http://www.transifex.com/tine20/tine20/language/nl_NL/)\nLanguage: nl_NL\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Password for download required"
: ""

, "Submit"
: ""

, "File not found!"
: ""

, "Name"
: "Naam"

, "Size"
: "Grootte"

, "Last Modified"
: "Laatst gewijzigd"

, "Description"
: "Omschrijving"

, "Folder, Folders"
: [
  "Folder"
 ,"Folders"

]
, "File, Files"
: [
  "Bestand"
 ,"Bestanden"

]
, "Default behavior when double-clicking on a Row"
: ""

, "Defines which action should be executed by default when double-clicked."
: ""

, "Invalid Filename"
: ""

, "Content type"
: ""

, "path"
: "path"

, "URL"
: ""

, "Password"
: ""

, "Valid until"
: ""

, "Send as e-mail"
: ""

, "Download"
: ""

, "Create Public Link"
: "Maak publieke link"

, "Remove record"
: "Verwijder record"

, "Creating new Download Link..."
: "Maak nieuwe download link..."

, "Deleting Download Links..."
: "Verwijder dowload links..."

, "Deleting Download Link..."
: "Download links verwijderen..."

, "Created By"
: "Aangemaakt door"

, "Creation Time"
: "Tijdstip aanmaak"

, "Expiration Time"
: "Vervaltijd"

, "Access Count"
: ""

, "Last Modified Time"
: "Laatst gewijzigd op"

, "Last Modified By"
: "Laatst gewijzigd door"

, "Revision"
: "Versie"

, "This folder has own revision settings"
: ""

, "Revision active"
: ""

, "Limit revision amount to"
: ""

, "Hold-back in months"
: ""

, "Upload Failed"
: "Upload mislukt"

, "It is not permitted to store files in this folder!"
: ""

, "Select a file"
: ""

, "Select files"
: ""

, "Select a folder"
: ""

, "Select folders"
: ""

, "Select an item"
: ""

, "Select items"
: ""

, "Checking ..."
: ""

, "Overwrite Existing File?"
: ""

, "Do you really want to overwrite the selected file?"
: ""

, "Tags"
: "Tags"

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Indexed"
: ""

, "File contents is part of the search index"
: ""

, "Upload"
: "Upload"

, "Open Data Safe"
: ""

, "Folder Up"
: "Folder omhoog"

, "Close Data Safe"
: ""

, "Filemanager"
: "Bestandsbeheerder"

, "Save locally"
: "Bewaar lokaal"

, "Close"
: ""

, "Loading preview ..."
: ""

, "Edit folder"
: "M"

, "edit file"
: "Bewerk bestand"

, "Public Links"
: "Publieke links"

, "Type"
: "Type"

, "Not yet indexed"
: ""

, "Modified By"
: "Gewijzigd door"

, "Enter description"
: "Voer omschrijving in"

, "Service Unavailable"
: "Service niet beschikbaar"

, "The Filemanager is not configured correctly. Please refer to the {0}Tine 2.0 Admin FAQ{1} for configuration advice or contact your administrator."
: "Bestandsbeheer is niet juist geconfigureerd. Raadpleeg de {0} Tine 2.0 Admin FAQ {1} voor advies of neem contact op met de beheerder."

, "File(s) already exists"
: ""

, "Do you want to replace the following file(s)?"
: "Bestand(en) verplaatsten?"

, "An error occurred creating this folder"
: ""

, "Item with this name already exists!"
: "Item met deze naam bestaat al!"

, "Whole Filemanager"
: ""

, "This Folder"
: ""

, "Search"
: ""

, "The grant to download files"
: ""

, "Publish"
: "Publiceer"

, "The grant to create anonymous download links for files"
: ""

, "Copying data .. {0}"
: "Kopieren gegevens... {0}"

, "Moving data .. {0}"
: "Verplaatsen gegevens... {0}"

, "Please wait"
: "Moment"

, "Error while uploading \"{fileName}\". Please try again later."
: ""

, "Quick Search"
: "Snel zoeken"

, "Content Type"
: ""

, "File Contents"
: ""

, "Download Link, Download Links"
: [
  ""
 ,""

]
, "Node Download Links"
: "Knooppunt Download Links"

, "Sorry, Tine 2.0 would have liked to show you the contents of the file."
: ""

, "This is possible for .doc, .jpg, .pdf and even more file formats."
: ""

, "Interested? Then let us know!"
: ""

, "We would be happy to make you a non-binding offer."
: ""

, "No preview available yet - Please try again in a few minutes."
: ""

, "Notifications"
: ""

, "This folder has own notification settings"
: ""

, "Notification"
: ""

, "Notification active"
: ""

, "Summary"
: ""

, "Once a Day, Every {0} Days"
: [
  ""
 ,""

]
, "No"
: ""

, "Don't summarize"
: ""

, "Once a day"
: ""

, "Every 3 days"
: ""

, "Once a week"
: ""

, "Once a month"
: ""

, "Once a year"
: ""

, "Search for users ..."
: ""

, "No permission"
: ""

, "all"
: ""

, "Search for groups ..."
: ""

, "Grants"
: ""

, "This folder has its own grants"
: ""

, "Grants of a folder also apply recursively to all sub folders unless they have their own grants."
: ""

, "This folder is part of the data safe"
: ""

, "If the data safe is activated, this folder and its contents can only be accessed when the data safe is open."
: ""

, "Usage"
: ""

, "This folder has own quota"
: ""

, "Quota"
: ""

, "No quota set (examples: 10 GB, 900 MB)"
: ""

, "Current Usage"
: ""

, "The quota applies recursively to files and subfolders. Please note, the effective quota can differ if a parent folder has set a lower quota."
: ""

, "File Type"
: ""

, "Usage by File Type"
: ""

, "User"
: ""

, "Usage by User"
: ""

, "unknown"
: ""

, "Reload"
: ""

, "Create Folder"
: "Maak folder"

, "New Folder"
: "Nieuwe folder"

, "Please enter the name of the new folder:"
: "Geef de naam van de nieuwe folder:"

, "No {0} added"
: "Geen {0} toegevoegd"

, "You have to supply a {0} name!"
: "Er moet een {0} naam worden opgegeven!"

, "Edit Properties"
: "Bewerk eigenschappen"

, "Rename"
: ""

, "Rename {0}"
: ""

, "Please enter the new name of the {0}:"
: "Voer de nieuwe naam van de {0} in:"

, "Not renamed {0}"
: "{0} niet hernoemd"

, "System Link"
: ""

, "Use this link to share the entry with other system users"
: ""

, "Delete"
: "Verwijder"

, "Do you really want to delete the following files?"
: "Mogewn de volgende bestanden echt worden verwijderd?"

, "Move"
: ""

, "Move Items"
: ""

, "Preview"
: ""

, "Download links can be protected with a password. If no password is specified, anyone who knows the link can access the selected files."
: ""

, "Folder has been published successfully"
: "Map is met succes gepubliceerd"

, "File has been published successfully"
: "Bestand is met succes gepubliceerd"

, "Public Download URL"
: ""

, "Deliver anonymous downloads from another URL. Make sure the rewrite rules are adjusted accordingly."
: ""

, "you can't remove your own admin grant"
: ""

, "My folders"
: "Mijn folders"

, "Shared folders"
: "Gedeelde folders"

, "Other users folders"
: "Folders van andere gebruikers"

, "Received"
: ""

, "To"
: ""

, "Cc"
: ""

, "Bcc"
: ""

, "From (E-Mail)"
: ""

, "From (Name)"
: ""

, "Body"
: ""

, "Attachments"
: ""

, "Destination is a Subfolder"
: "Bestemming is een submap"

, "The destination is a subfolder. It is not allowed to copy or move a folder into one of its subfolders."
: "De bestemming is een submap. Het is niet toegestaan om te kopiëren of verplaatsen van een map in een van de submappen."

, "Destination has the same Path"
: "Bestemming heeft dezelfde pad"

, "The destination has the same path as the source. No action has been performed."
: ""

, "manage shared folders"
: "beheer gedeelde folders"

, "Create new shared folders"
: "Maak een nieuwe gedeelde folder"

, "Manage anonymous download links"
: "Beheer anonieme download links"

, "Allow viewing, adding and deleting download links"
: ""








, "Folder"
: "Folder"

, "File"
: "Bestand"

, "Download Link"
: ""

, "Once a Day"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
